<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation>Copyright © 2011–%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus</source>
        <translation>Datamaskinmotstander for brettspillet Blokus</translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation>Pentobi %1</translation>
    </message>
</context>
<context>
    <name>Actions</name>
    <message>
        <source>Main Variation</source>
        <translation type="vanished">Hovedvariasjon</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation type="vanished">Begynnelse av forgreining</translation>
    </message>
    <message>
        <source>Settings…</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation type="vanished">Innstillinger</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation type="vanished">Finn trekk</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation type="vanished">Neste kommentar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Fullskjermsvisning</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation type="vanished">Trekknummer…</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation type="vanished">Pentobi-hjelp</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="vanished">Ny</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation type="vanished">Vurdert spill</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation type="vanished">Åpne…</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="vanished">Spill</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation type="vanished">Spill enkelt trekk</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="vanished">Avslutt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Lagre</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation type="vanished">Lagre som…</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stopp</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation type="vanished">Angre trekk</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation type="vanished">Spillinfo</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="vanished">Kommentar</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation type="vanished">Innstillinger</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation>Analysehastighet:</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Rask</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Treg</translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>(Ingen analyse)</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation>Koordinater</translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation>Vis variasjoner</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Lys</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Mørk</translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation>Fargeblind lys</translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation>Fargeblind mørk</translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation>System</translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation>Flytt markering:</translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation>Siste med punkt</translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation>Siste med nummer</translation>
    </message>
    <message>
        <source>All with number</source>
        <translation>Alle med nummer</translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>Animasjoner</translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation>Vis kommentar:</translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Alltid</translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Ved behov</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation>Fargepalett:</translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation>Trekknummer</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialog</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>Eksporter ASCII-kunst</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>Tekstfiler</translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation>Gå til trekk %1</translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation>Flytt anmerkning</translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation>Flytt anmerkning (%1)</translation>
    </message>
</context>
<context>
    <name>ButtonApply</name>
    <message>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation>Datamaskinen spiller:</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation type="vanished">Blå/rød</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="vanished">Lilla</translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="vanished">Grønn</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="vanished">Blå</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation type="vanished">Gul/grønn</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="vanished">Oransje</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="vanished">Gul</translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="vanished">Rød</translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation>Nivå %1</translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation>Bildebredde:</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <source>Overwrite file?</source>
        <translation>Overskriv fil?</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation>Spiller blå/rød:</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>Spiller lilla:</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>Spiller grønn:</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>Spiller blå:</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>Spiller gul/grønn:</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>Spiller oransje:</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>Spiller gul:</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>Spiller rød:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Dato:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Hendelse:</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>Runde:</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Blue/Red</source>
        <translation type="vanished">Blå/rød</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="vanished">Lilla</translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="vanished">Grønn</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="vanished">Blå</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation type="vanished">Gul/grønn</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="vanished">Oransje</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="vanished">Gul</translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="vanished">Rød</translation>
    </message>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>Lilla vinner med ett poeng.</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>Lilla vinner med %L1 poeng.</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>Oransje vinner med ett poeng.</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>Oransje vinner med %L1 poeng.</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>Spillet slutter uavgjort.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Grønn vinner med ett poeng.</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>Grønn vinner med %L1 poeng.</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Blå vinner med ett poeng.</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>Blå vinner med %L1 poeng.</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Grønn vinner (uavgjort tilstand løst).</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Blå/rød vinner med ett poeng.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>Blå/rød vinner med %L1 poeng.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Gul/grønn vinnner med ett poeng.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>Gul/grønn vinner med %L1 poeng.</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Gul/grønn vinner (uavgjort tilstand løst).</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Blå vinner.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Gul vinner.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Rød vinner.</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Rød vinner (uavgjort tilstand løst).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Gul vinner (uavgjirt tilstand løst).</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>Spillet slutter uavgjort mellom blå og gul.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>Spillet slutter uavgjort mellom blå og rød.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>Spillet slutter uavgjort mellom gul og rød.</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>Spillet slutter uavgjort mellom alle spillere.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Grønn vinner.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>Spillet slutter uavgjort mellom blå, gul og rød.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>Spillet slutter uavgjort mellom blå, gul og grønn.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>Spillet slutter uavgjort mellom blå, rød og grønn.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>Spillet slutter uavgjort mellom gul, rød og grønn.</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>Ugyldig Blokus SGF-fil. (%1)</translation>
    </message>
    <message>
        <source>Clipboard is empty.</source>
        <translation>Utklippstavlen er tom.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Uten tittel</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <extracomment>The argument is a number, which will be increased if a file with the same name already exists</extracomment>
        <translation>Uten tittel %1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <extracomment>The argument is a number, which will be increased if a folder with the same name already exists</extracomment>
        <translation>Ny mappe %1</translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation>(Oppsett)</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>(Ingen trekk)</translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation>Trekk %1</translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation>Ustøttet tegnsett</translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation>Klassisk</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation>Trigon</translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation>Nexos</translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation>GembloQ</translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation>Callisto</translation>
    </message>
    <message>
        <source>Players:</source>
        <translation>Spillere:</translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation>Farger:</translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation>Datamaskinen tenker…</translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation>Kjører spillanalyse…</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation>Datamaskinen tenker… (opptil %1 sekunder gjenstår)</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation>Datamaskinen tenker… (opptil %1 minutter gjenstår)</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation>Trekknummer:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi-hjelp</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>Lagre bilde</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>PNG-bildefiler</translation>
    </message>
    <message>
        <source>JPEG image files</source>
        <translation>JPEG-bildefiler</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation>Hent din vurdering for denne spillvarianten.</translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation>Startsvurdering:</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Begynner</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Ekspert</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>Spillanalyse er kun tilgjengelig i hovedvariasjonen.</translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation>Automatisk lagret spill ble endret av en annen kjørende utgave av Pentobi. Overskriv?</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Din vurdering har økt fra %1 til %2.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Din vurdering har sunket fra %1 til %2.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Din vurdering forblir %1.</translation>
    </message>
    <message>
        <source>No permission to access storage</source>
        <translation>Mangler lagringstilgang</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>Slett all vurderingsinformasjon fra nåværende spillvariant?</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>Slett alle variasjoner?</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>Lagring mislyktes.</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>Nådde slutten av treet. Fortsett søket fra starten av treet?</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>Ingen kommentar funnet</translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation>%1 (endret)</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>Filen har blitt endret av et annet program. Last inn på nytt?</translation>
    </message>
    <message>
        <source>Continue computer move?</source>
        <translation>Fortsett datamaskintrekk?</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>Kun behold posisjonen?</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>Kun behold undertreet?</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>Åpning mislyktes.</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>Start vurdert spill med lilla mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>Start vurdert spill med grønn mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>Start vurdert spill med blå/rød mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>Start vurdert spill med blå mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>Start vurdert spill med oransje mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>Start vurdert spill med gul/grønn mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>Start vurdert spill med gul mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>Start vurdert spill med rød mot Pentobi nivå %1?</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation>Du har ikke spillt noen vurderte spill i denne varianten enda.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>Forkort dette undertreet?</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>Forkort underprosess?</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>Forkast spill?</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation>Pentobi %1 (nivå %2)</translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation>Menneske</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>Vurdert spill</translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation>Filen har blitt endret av et annet program. Overskriv?</translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation>%1 - Pentobi</translation>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation>Ikke nok minne</translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation>Spillanalyse avbrutt</translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation>Datamaskintrekk avbrutt</translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation>Vurderingsinformasjon slettet</translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation>Variasjoner slettet</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>Fil lagret</translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation>Lagring av bilde mislyktes, eller ustøttet bildeformat</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation>Bilde lagret</translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation>Oppretting av bilde mislyktes</translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation>Fortsetter vurdert spill</translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation>Beholdt kun posisjonen</translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation>Beholdte kun undertre</translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation>Varianten er nå %1</translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation>Underprosess forkortet</translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation>Oppsett</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Oppsettsmodus</translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation>Vurdert</translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation>Vurdert %1</translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation>Vurdert spill %1</translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation>Hovedvariasjon</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation>Begynnelse av forgreining</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation>Finn trekk</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation>Neste kommentar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskjermsvisning</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation>Spillinfo</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation>Trekknummer…</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi-hjelp</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation>Vurdert spill</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation>Åpne…</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spill</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation>Spill enkelt trekk</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation>Lagre som…</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation>Angre trekk</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Blå/rød</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Lilla</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Grønn</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blå</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Gul/grønn</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Oransje</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Gul</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rød</translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation>Datamaskin</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
        <translation>D</translation>
    </message>
    <message>
        <source>S</source>
        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
        <translation>L</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
        <translation>S</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>E</source>
        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
        <translation>R</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
        <translation>H</translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation>Gjør til hovedvariasjon</translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation>Variasjon oppover</translation>
    </message>
    <message>
        <source>U</source>
        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation>Variasjon nedover</translation>
    </message>
    <message>
        <source>W</source>
        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>Slett variasjoner</translation>
    </message>
    <message>
        <source>D</source>
        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
        <translation>S</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>Forkort</translation>
    </message>
    <message>
        <source>T</source>
        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>Forkort underprosess</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
        <translation>U</translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation>Behold posisjon</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation>Behold undertreet</translation>
    </message>
    <message>
        <source>S</source>
        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
        <translation>T</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Oppsettsmodus</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
        <translation>M</translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation>Neste farge</translation>
    </message>
    <message>
        <source>N</source>
        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation>Anmerkning…</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation>Gjort til hovedvariasjon</translation>
    </message>
</context>
<context>
    <name>MenuExport</name>
    <message>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <source>E</source>
        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>Image…</source>
        <translation>Bilde…</translation>
    </message>
    <message>
        <source>ASCII Art…</source>
        <translation>ASCII-kunst…</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation>Spil</translation>
    </message>
    <message>
        <source>G</source>
        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
        <translation>S</translation>
    </message>
    <message>
        <source>N</source>
        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>R</source>
        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
        <translation>U</translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation>Spillvariant…</translation>
    </message>
    <message>
        <source>V</source>
        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
        <translation>V</translation>
    </message>
    <message>
        <source>I</source>
        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
    <message>
        <source>U</source>
        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>F</source>
        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>Open Clipboard</source>
        <translation>Åpne utklippstavle</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
        <translation>K</translation>
    </message>
    <message>
        <source>S</source>
        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
        <translation>L</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
        <translation>S</translation>
    </message>
    <message>
        <source>Q</source>
        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
        <translation>T</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation>Gå</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
        <translation>G</translation>
    </message>
    <message>
        <source>N</source>
        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
        <translation>H</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
        <translation>K</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>H</source>
        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
        <translation>H</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation>Om Pentobi</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
    <message>
        <source>Report Bug</source>
        <translation>Innrapporter feil</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>MenuItem</name>
    <message>
        <source>Ctrl</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Shift</translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation>Åpne nylige</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
        <translation>Y</translation>
    </message>
    <message>
        <source>%1. %2</source>
        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
        <translation>%1. %2</translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation>Tøm liste</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
        <translation>T</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation>Verktøy</translation>
    </message>
    <message>
        <source>T</source>
        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Vurdering</translation>
    </message>
    <message>
        <source>R</source>
        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
        <translation>U</translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation>Fjern vurdering</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>Analyze Game</source>
        <translation type="vanished">Analyser spill</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation>Tøm analyse</translation>
    </message>
    <message>
        <source>E</source>
        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation>Analyser spill…</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>V</source>
        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
        <translation>V</translation>
    </message>
    <message>
        <source>Appearance…</source>
        <translation type="vanished">Utseende…</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
        <translation>U</translation>
    </message>
    <message>
        <source>F</source>
        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
        <translation>K</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Verktøyslinje</translation>
    </message>
    <message>
        <source>T</source>
        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation>Trekk %1</translation>
    </message>
    <message>
        <source>Very good</source>
        <translation>Veldig god</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>God</translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation>Interessant</translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation>Tvilsom</translation>
    </message>
    <message>
        <source>Bad</source>
        <translation>Dårlig</translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation>Veldig dårlig</translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation>Ingen tilknytning</translation>
    </message>
</context>
<context>
    <name>NewFolderDialog</name>
    <message>
        <source>Folder name:</source>
        <translation>Mappenavn:</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Blokus-spill</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation>Din vurdering:</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Spillvariant:</translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation>Klassisk (2)</translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation>Klassisk (3)</translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation>Klassisk (4)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation>Trigon (2)</translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation>Trigon (3)</translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation>Trigon (4)</translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation>Nexos (2)</translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation>Nexos (4)</translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation>Callisto (2)</translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation>Callisto (2/4)</translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation>Callisto (3)</translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation>Callisto (4)</translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation>GembloQ (4)</translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation>GembloQ (2)</translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation>GembloQ (2/4)</translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation>GembloQ (3)</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>Vurderte spill:</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Beste tidligere vurdering:</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Nylig utvikling:</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">Spil</translation>
    </message>
    <message>
        <source>Result</source>
        <translation type="vanished">Resultat</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation type="vanished">Vunnet</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation type="vanished">Tapt</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation type="vanished">Uavgjort</translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="vanished">Nivå</translation>
    </message>
    <message>
        <source>Your Color</source>
        <translation type="vanished">Din farge</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="vanished">Dato</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation type="vanished">Åpne spill %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Blokus-spill</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation>Spil</translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation>Resultat</translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation>Nivå</translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation>Din farge</translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation>Vunnet</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation>Tapt</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation>Uavgjort</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation>Start nytt spill</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>Start vurdert spill</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>Sett fargene spilt av datamaskinen</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>Få datamaskinen til å fortsette å spille gjeldende farge</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>Få datamaskinen til å spille gjeldende farge</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>Gå til begynnelsen av spillet</translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation>Gå ti trekk tilbake</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>Gå ett steg bakover</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>Gå ett steg forover</translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation>Gå ti trekk forover</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>Gå til trekkslutt</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>Gå til forrige variasjon</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>Gå til neste variasjon</translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation>Avbryt spillanalyse</translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation>Avbryt datamaskintrekk</translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation>Angre trekk</translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation>datamaskinsmotstander for brettspillet Blokus</translation>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation>Sett maksimumsnivå til &lt;n&gt;.</translation>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation>Ikke bruk åpningsbøker.</translation>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation>Bruk visning optimalisert for smarttelefoner.</translation>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation>Ikke forsink raske datamaskintrekk.</translation>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation type="unfinished">Sett tilfeldig seeding til &lt;n&gt;.</translation>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation>Bruk &lt;n&gt; tråder (0=auto).</translation>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation>Skriv loggingsinfo til forvalg for feil.</translation>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation>fil.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation>Blokus SGF-fil å åpne (valgfritt).</translation>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation>--maxlevel må være mellom 1 og %1</translation>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation>--seed må være et positivt tall</translation>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation>--treads må være et positivt tall</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>For mange argumenter</translation>
    </message>
</context>
</TS>
